<?php
/**
 * Theme functions and definitions
 *
 * @package SEO Agency Lite
 */ 

if ( ! function_exists( 'seo_agency_lite_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function seo_agency_lite_enqueue_styles() {
		wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri()).'/css/bootstrap.css' );
		wp_enqueue_style( 'seo-agency-lite-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'seo-agency-lite-style', get_stylesheet_directory_uri() . '/style.css', array( 'seo-agency-lite-style-parent' ), '1.0.0' );

		require get_theme_file_path( '/tc-style.php' );
		wp_add_inline_style( 'seo-agency-lite-style',$seo_agency_lite_custom_css );

		require get_parent_theme_file_path( '/tc-style.php' );
		wp_add_inline_style( 'seo-agency-lite-style-parent',$digital_advertising_custom_css );
	}
endif;
add_action( 'wp_enqueue_scripts', 'seo_agency_lite_enqueue_styles');

function seo_agency_lite_customize_register() {
	global $wp_customize;
	$wp_customize->remove_setting( 'digital_advertising_show_topbar' );
	$wp_customize->remove_control( 'digital_advertising_show_topbar' );
	$wp_customize->remove_setting( 'digital_advertising_noof_list' );
	$wp_customize->remove_control( 'digital_advertising_noof_list' );
	$wp_customize->remove_setting( 'digital_advertising_topbar_location' );
	$wp_customize->remove_control( 'digital_advertising_topbar_location' );
	$wp_customize->remove_setting( 'digital_advertising_about_page' );
	$wp_customize->remove_control( 'digital_advertising_about_page' );
	
    $wp_customize->add_setting('digital_advertising_phoneno_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('digital_advertising_phoneno_text',array(
		'label'	=> __('Add Phone Text','seo-agency-lite'),
		'section' => 'digital_advertising_topbar',
		'type'	=> 'text'
	));
	
    $wp_customize->add_setting('digital_advertising_email_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('digital_advertising_email_text',array(
		'label'	=> __('Add Email Text','seo-agency-lite'),
		'section' => 'digital_advertising_topbar',
		'type'	=> 'text'
	));

	$args = array('numberposts' => -1);
	$post_list = get_posts($args);
	$i = 0;
	$posts[]='Select';	
	foreach($post_list as $post){
		$posts[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('seo_agency_lite_about_post',array(
		'sanitize_callback' => 'digital_advertising_sanitize_choices',
	));
	$wp_customize->add_control('seo_agency_lite_about_post',array(
		'type'    => 'select',
		'choices' => $posts,
		'label' => __('Select post','seo-agency-lite'),
		'section' => 'digital_advertising_about_section',
	));
}
add_action( 'customize_register', 'seo_agency_lite_customize_register', 11 );

/* Theme Setup */
if ( ! function_exists( 'seo_agency_lite_setup' ) ) :

function seo_agency_lite_setup() {

	$GLOBALS['content_width'] = apply_filters( 'seo_agency_lite_content_width', 640 );

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('seo-agency-lite-homepage-thumb',240,145,true);
	
   	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'seo-agency-lite' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );
	
	add_theme_support ('html5', array (
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

	add_theme_support('responsive-embeds');

	/* Selective refresh for widgets */
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', digital_advertising_font_url() ) );

	// Dashboard Theme Notification
	global $pagenow;
	
	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'seo_agency_lite_activation_notice' );
	}

}
endif;
add_action( 'after_setup_theme', 'seo_agency_lite_setup' );

// Dashboard Theme Notification
function seo_agency_lite_activation_notice() {
	echo '<div class="welcome-notice notice notice-success is-dimdissible">';
		echo '<h2>'. esc_html__( 'Thank You!!!!!', 'seo-agency-lite' ) .'</h2>';
		echo '<p>'. esc_html__( 'Much grateful to you for choosing our seo agency lite theme from themescaliber. we praise you for opting our services over others. we are obliged to invite you on our welcome page to render you with our outstanding services.', 'seo-agency-lite' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=seo_agency_lite_guide' ) ) .'" class="button button-primary">'. esc_html__( 'Click Here...', 'seo-agency-lite' ) .'</a></p>';
	echo '</div>';
}

function seo_agency_lite_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'seo-agency-lite' ),
		'description'   => __( 'Appears on blog page sidebar', 'seo-agency-lite' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s mb-4 p-2">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pt-0">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'seo_agency_lite_widgets_init' );

function seo_agency_lite_enqueue_comments_reply() {
    if( is_singular() && comments_open() && ( get_option( 'thread_comments' ) == 1) ) {
        wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
    }
}
add_action( 'wp_enqueue_scripts', 'seo_agency_lite_enqueue_comments_reply' );

add_action( 'init', 'seo_agency_lite_remove_action');
function seo_agency_lite_remove_action() {
    remove_action( 'admin_menu','digital_advertising_gettingstarted' );
    remove_action( 'admin_notices','digital_advertising_activation_notice' );
}

// URL DEFINES
define('SEO_AGENCY_LITE_SUPPORT',__('https://wordpress.org/support/theme/seo-agency-lite/','seo-agency-lite'));
define('SEO_AGENCY_LITE_REVIEW',__('https://wordpress.org/support/theme/seo-agency-lite/reviews/','seo-agency-lite'));
define('SEO_AGENCY_LITE_BUY_NOW',__('https://www.themescaliber.com/themes/seo-agency-wordpress-theme/','seo-agency-lite'));
define('SEO_AGENCY_LITE_LIVE_DEMO',__('https://www.themescaliber.com/seo-agency-pro/','seo-agency-lite'));
define('SEO_AGENCY_LITE_PRO_DOC',__('https://themescaliber.com/demo/doc/seo-agency-pro/','seo-agency-lite'));
define('SEO_AGENCY_LITE_CHILD_THEME',__('https://developer.wordpress.org/themes/advanced-topics/child-themes/','seo-agency-lite'));
define('SEO_AGENCY_LITE_THEME_URL',__('https://www.themescaliber.com/themes/free-seo-wordpress-theme/', 'seo-agency-lite'));

if ( ! defined( 'DIGITAL_ADVERTISING_PRO_NAME' ) ) {
	define( 'DIGITAL_ADVERTISING_PRO_NAME', esc_html__( 'SEO Agency Pro', 'seo-agency-lite' ));
}
if ( ! defined( 'DIGITAL_ADVERTISING_PRO_URL' ) ) {
	define( 'DIGITAL_ADVERTISING_PRO_URL', esc_url('https://www.themescaliber.com/themes/seo-agency-wordpress-theme/'));
}

function seo_agency_lite_credit_link() {
    echo "<a href=".esc_url(SEO_AGENCY_LITE_THEME_URL)." target='_blank'>".esc_html__('Seo Agency WordPress Theme','seo-agency-lite')."</a>";
}

/* Webfonts */
require get_theme_file_path() . '/wptt-webfont-loader.php';

/* Implement the get started page */
require get_theme_file_path() . '/inc/dashboard/getstart.php';